@@ -11,6 +11,10 @@ if PYQT_VERSIONS == "PyQt5":
         QUrl,
         QRectF,
         QRect,
+        QPropertyAnimation,
+        QThread,
+        QEasingCurve,
+        QByteArray
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -24,7 +28,10 @@ if PYQT_VERSIONS == "PyQt6":
         QUrl,
         QRectF,
         QRect,
-
+        QPropertyAnimation,
+        QThread,
+        QEasingCurve,
+        QByteArray
     )
 
 if PYQT_VERSIONS == "PySide2":
@@ -38,6 +45,10 @@ if PYQT_VERSIONS == "PySide2":
         QUrl,
         QRectF,
         QRect,
+        QPropertyAnimation,
+        QThread,
+        QEasingCurve,
+        QByteArray
     )
 if PYQT_VERSIONS == "PySide6":
     from PySide6.QtCore import (
@@ -50,4 +61,8 @@ if PYQT_VERSIONS == "PySide6":
         QUrl,
         QRectF,
         QRect,
+        QPropertyAnimation,
+        QThread,
+        QEasingCurve,
+        QByteArray
     )
\ No newline at end of file
